import abilityAccessCtrl from "@ohos:abilityAccessCtrl";
import type { Permissions } from "@ohos:abilityAccessCtrl";
import type common from "@ohos:app.ability.common";
import bundleManager from "@ohos:bundle.bundleManager";
import type { BusinessError } from "@ohos:base";
const TAG: string = '[PermissionUtil]';
class PermissionUtil {
    private context: common.UIAbilityContext = getContext(this) as common.UIAbilityContext;
    // 获取应用程序的accessTokenID
    private async checkAccessToken(permission: Permissions): Promise<abilityAccessCtrl.GrantStatus> {
        let atManager = abilityAccessCtrl.createAtManager();
        let grantStatus: abilityAccessCtrl.GrantStatus = abilityAccessCtrl.GrantStatus.PERMISSION_DENIED;
        // 获取token
        let tokenId: number = 0;
        try {
            let bundleInfo: bundleManager.BundleInfo = await bundleManager.getBundleInfoForSelf(bundleManager.BundleFlag.GET_BUNDLE_INFO_WITH_APPLICATION);
            let appInfo: bundleManager.ApplicationInfo = bundleInfo.appInfo;
            tokenId = appInfo.accessTokenId;
        }
        catch (err) {
            console.error(`getBundleInfoForSelf failed, code is ${err.code}, message is ${err.message}`);
        }
        // 校验权限
        try {
            grantStatus = await atManager.checkAccessToken(tokenId, permission);
        }
        catch (err) {
            console.error(`checkAccessToken failed, code is ${err.code}, message is ${err.message}`);
        }
        return grantStatus;
    }
    // 检查用户权限
    async checkPermissions(permissions: Array<Permissions>): Promise<Boolean> {
        let hasAllPermission = true;
        console.info(TAG, "checkPermissions:" + permissions);
        for (const permission of permissions) {
            let grantStatus: abilityAccessCtrl.GrantStatus = await this.checkAccessToken(permission);
            if (grantStatus !== abilityAccessCtrl.GrantStatus.PERMISSION_GRANTED) {
                console.error(TAG, "don't have permission:" + permission);
                hasAllPermission = false;
            }
            console.info(TAG, "hasAllPermission:" + hasAllPermission);
            return hasAllPermission;
        }
        return hasAllPermission;
    }
    // 请求用户权限
    requestPermissions(permissions: Array<Permissions>): void {
        let atManager = abilityAccessCtrl.createAtManager();
        console.info(TAG, "requestPermissions:" + permissions);
        try {
            atManager.requestPermissionsFromUser(this.context, permissions).then((data) => {
                console.info(TAG, "requestPermissions result:" + JSON.stringify(data));
            }).catch((err: BusinessError) => {
                console.info(TAG, "requestPermissions failed:" + JSON.stringify(err));
            });
        }
        catch (err) {
            console.error(TAG, `catch err->${JSON.stringify(err)}`);
        }
    }
}
export default new PermissionUtil();
